# Charactor progress (name in Chinese)

- [X] 凯亚
- [X] 重云
- [X] 神里绫华
- [X] 甘雨
- [X] 迪奥娜
- [X] 优菈
- [X] 愚人众·冰萤术士
- [X] 申鹤
- [X] 七七
- [X] 凝光
- [X] 诺艾尔
- [X] 丘丘岩盔王
- [X] 荒泷一斗
- [X] 钟离
- [X] 阿贝多
- [X] 纯水精灵·洛蒂娅
- [X] 愚人众·藏镜仕女
- [X] 芭芭拉
- [X] 行秋
- [X] 莫娜
- [X] 珊瑚宫心海
- [X] 神里绫人
- [X] 达达利亚
- [X] 坎蒂丝
- [X] 迪卢克
- [X] 香菱
- [X] 班尼特
- [X] 愚人众·火之债务处理人
- [X] 宵宫
- [X] 可莉
- [X] 安柏
- [X] 胡桃
- [X] 深渊咏者·渊火
- [X] 烟绯
- [X] 柯莱
- [X] 翠翎恐蕈
- [X] 提纳里
- [X] 纳西妲
- [X] 雷泽
- [X] 刻晴
- [X] 赛诺
- [X] 菲谢尔
- [X] 北斗
- [X] 九条裟罗
- [X] 无相之雷
- [X] 雷电将军
- [X] 八重神子
- [X] 丽莎
- [X] 砂糖
- [X] 魔偶剑鬼
- [X] 琴
- [X] 温迪
- [X] 魈
- [X] 枫原万叶